import React, { HTMLAttributes } from "react";
export interface Props extends HTMLAttributes<HTMLButtonElement> {
    showPercent?: boolean;
    percent?: number;
    children?: React.ReactNode | React.ReactNodeArray;
    buttonRef?: any;
}
export declare class CircularButton extends React.PureComponent<Props> {
    buttonRef: any;
    constructor(props: Props);
    render(): JSX.Element;
}
