export function createElement(node: any, index: any, data: any, children: any): React.ReactElement<{}, string | React.JSXElementConstructor<any>>;
import React = require("react");
//# sourceMappingURL=utils.d.ts.map