"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const block_1 = __importDefault(require("./block"));
const inline_1 = __importDefault(require("./inline"));
function mathPlugin(opts = {}) {
    block_1.default.call(this, opts);
    inline_1.default.call(this, opts);
}
exports.mathPlugin = mathPlugin;
exports.default = mathPlugin;
