import React, { FC, HTMLAttributes } from "react";
export interface ToolbarItemProps extends HTMLAttributes<HTMLDivElement> {
    image: React.ReactNode;
    text: string;
    showText?: boolean;
    showButton?: boolean;
    onClick: () => void;
    buttonClassName?: string;
}
export declare const ToolbarItem: FC<ToolbarItemProps>;
