declare module "react-syntax-highlighter/dist/cjs/styles/prism/vs" {
    const style: any;
    export default style;
}

declare module "react-syntax-highlighter/dist/cjs/styles/prism/xonokai" {
    const style: any;
    export default style;
}