/// <reference types="react" />
import ReactMarkdown from "react-markdown";
import { Attachments } from "./attachment/attachment-transformer";
interface MarkDownRenderProps extends ReactMarkdown.ReactMarkdownProps {
    attachments?: Attachments;
}
declare const MarkdownRender: (props: MarkDownRenderProps) => JSX.Element;
export default MarkdownRender;
