/*
 * Copyright 2021 Palantir Technologies, Inc. All rights reserved.
 */

@import "icon-variables";
$icons: (
  "add": $pt-icon-add,
  "add-column-left": $pt-icon-add-column-left,
  "add-column-right": $pt-icon-add-column-right,
  "add-row-bottom": $pt-icon-add-row-bottom,
  "add-row-top": $pt-icon-add-row-top,
  "add-to-artifact": $pt-icon-add-to-artifact,
  "add-to-folder": $pt-icon-add-to-folder,
  "airplane": $pt-icon-airplane,
  "align-center": $pt-icon-align-center,
  "align-justify": $pt-icon-align-justify,
  "align-left": $pt-icon-align-left,
  "align-right": $pt-icon-align-right,
  "alignment-bottom": $pt-icon-alignment-bottom,
  "alignment-horizontal-center": $pt-icon-alignment-horizontal-center,
  "alignment-left": $pt-icon-alignment-left,
  "alignment-right": $pt-icon-alignment-right,
  "alignment-top": $pt-icon-alignment-top,
  "alignment-vertical-center": $pt-icon-alignment-vertical-center,
  "annotation": $pt-icon-annotation,
  "application": $pt-icon-application,
  "applications": $pt-icon-applications,
  "archive": $pt-icon-archive,
  "arrow-bottom-left": $pt-icon-arrow-bottom-left,
  "arrow-bottom-right": $pt-icon-arrow-bottom-right,
  "arrow-down": $pt-icon-arrow-down,
  "arrow-left": $pt-icon-arrow-left,
  "arrow-right": $pt-icon-arrow-right,
  "arrow-top-left": $pt-icon-arrow-top-left,
  "arrow-top-right": $pt-icon-arrow-top-right,
  "arrow-up": $pt-icon-arrow-up,
  "arrows-horizontal": $pt-icon-arrows-horizontal,
  "arrows-vertical": $pt-icon-arrows-vertical,
  "asterisk": $pt-icon-asterisk,
  "automatic-updates": $pt-icon-automatic-updates,
  "badge": $pt-icon-badge,
  "ban-circle": $pt-icon-ban-circle,
  "bank-account": $pt-icon-bank-account,
  "barcode": $pt-icon-barcode,
  "blank": $pt-icon-blank,
  "blocked-person": $pt-icon-blocked-person,
  "bold": $pt-icon-bold,
  "book": $pt-icon-book,
  "bookmark": $pt-icon-bookmark,
  "box": $pt-icon-box,
  "briefcase": $pt-icon-briefcase,
  "bring-data": $pt-icon-bring-data,
  "build": $pt-icon-build,
  "calculator": $pt-icon-calculator,
  "calendar": $pt-icon-calendar,
  "camera": $pt-icon-camera,
  "caret-down": $pt-icon-caret-down,
  "caret-left": $pt-icon-caret-left,
  "caret-right": $pt-icon-caret-right,
  "caret-up": $pt-icon-caret-up,
  "cell-tower": $pt-icon-cell-tower,
  "changes": $pt-icon-changes,
  "chart": $pt-icon-chart,
  "chat": $pt-icon-chat,
  "chevron-backward": $pt-icon-chevron-backward,
  "chevron-down": $pt-icon-chevron-down,
  "chevron-forward": $pt-icon-chevron-forward,
  "chevron-left": $pt-icon-chevron-left,
  "chevron-right": $pt-icon-chevron-right,
  "chevron-up": $pt-icon-chevron-up,
  "circle": $pt-icon-circle,
  "circle-arrow-down": $pt-icon-circle-arrow-down,
  "circle-arrow-left": $pt-icon-circle-arrow-left,
  "circle-arrow-right": $pt-icon-circle-arrow-right,
  "circle-arrow-up": $pt-icon-circle-arrow-up,
  "citation": $pt-icon-citation,
  "clean": $pt-icon-clean,
  "clipboard": $pt-icon-clipboard,
  "cloud": $pt-icon-cloud,
  "cloud-download": $pt-icon-cloud-download,
  "cloud-upload": $pt-icon-cloud-upload,
  "code": $pt-icon-code,
  "code-block": $pt-icon-code-block,
  "cog": $pt-icon-cog,
  "collapse-all": $pt-icon-collapse-all,
  "column-layout": $pt-icon-column-layout,
  "comment": $pt-icon-comment,
  "comparison": $pt-icon-comparison,
  "compass": $pt-icon-compass,
  "compressed": $pt-icon-compressed,
  "confirm": $pt-icon-confirm,
  "console": $pt-icon-console,
  "contrast": $pt-icon-contrast,
  "control": $pt-icon-control,
  "credit-card": $pt-icon-credit-card,
  "cross": $pt-icon-cross,
  "crown": $pt-icon-crown,
  "cube": $pt-icon-cube,
  "cube-add": $pt-icon-cube-add,
  "cube-remove": $pt-icon-cube-remove,
  "curved-range-chart": $pt-icon-curved-range-chart,
  "cut": $pt-icon-cut,
  "dashboard": $pt-icon-dashboard,
  "data-lineage": $pt-icon-data-lineage,
  "database": $pt-icon-database,
  "delete": $pt-icon-delete,
  "delta": $pt-icon-delta,
  "derive-column": $pt-icon-derive-column,
  "desktop": $pt-icon-desktop,
  "diagnosis": $pt-icon-diagnosis,
  "diagram-tree": $pt-icon-diagram-tree,
  "direction-left": $pt-icon-direction-left,
  "direction-right": $pt-icon-direction-right,
  "disable": $pt-icon-disable,
  "document": $pt-icon-document,
  "document-open": $pt-icon-document-open,
  "document-share": $pt-icon-document-share,
  "dollar": $pt-icon-dollar,
  "dot": $pt-icon-dot,
  "double-caret-horizontal": $pt-icon-double-caret-horizontal,
  "double-caret-vertical": $pt-icon-double-caret-vertical,
  "double-chevron-down": $pt-icon-double-chevron-down,
  "double-chevron-left": $pt-icon-double-chevron-left,
  "double-chevron-right": $pt-icon-double-chevron-right,
  "double-chevron-up": $pt-icon-double-chevron-up,
  "doughnut-chart": $pt-icon-doughnut-chart,
  "download": $pt-icon-download,
  "drag-handle-horizontal": $pt-icon-drag-handle-horizontal,
  "drag-handle-vertical": $pt-icon-drag-handle-vertical,
  "draw": $pt-icon-draw,
  "drive-time": $pt-icon-drive-time,
  "duplicate": $pt-icon-duplicate,
  "edit": $pt-icon-edit,
  "eject": $pt-icon-eject,
  "endorsed": $pt-icon-endorsed,
  "envelope": $pt-icon-envelope,
  "equals": $pt-icon-equals,
  "eraser": $pt-icon-eraser,
  "error": $pt-icon-error,
  "euro": $pt-icon-euro,
  "exchange": $pt-icon-exchange,
  "exclude-row": $pt-icon-exclude-row,
  "expand-all": $pt-icon-expand-all,
  "export": $pt-icon-export,
  "eye-off": $pt-icon-eye-off,
  "eye-on": $pt-icon-eye-on,
  "eye-open": $pt-icon-eye-open,
  "fast-backward": $pt-icon-fast-backward,
  "fast-forward": $pt-icon-fast-forward,
  "feed": $pt-icon-feed,
  "feed-subscribed": $pt-icon-feed-subscribed,
  "film": $pt-icon-film,
  "filter": $pt-icon-filter,
  "filter-keep": $pt-icon-filter-keep,
  "filter-list": $pt-icon-filter-list,
  "filter-open": $pt-icon-filter-open,
  "filter-remove": $pt-icon-filter-remove,
  "flag": $pt-icon-flag,
  "flame": $pt-icon-flame,
  "flash": $pt-icon-flash,
  "floppy-disk": $pt-icon-floppy-disk,
  "flow-branch": $pt-icon-flow-branch,
  "flow-end": $pt-icon-flow-end,
  "flow-linear": $pt-icon-flow-linear,
  "flow-review": $pt-icon-flow-review,
  "flow-review-branch": $pt-icon-flow-review-branch,
  "flows": $pt-icon-flows,
  "folder-close": $pt-icon-folder-close,
  "folder-new": $pt-icon-folder-new,
  "folder-open": $pt-icon-folder-open,
  "folder-shared": $pt-icon-folder-shared,
  "folder-shared-open": $pt-icon-folder-shared-open,
  "follower": $pt-icon-follower,
  "following": $pt-icon-following,
  "font": $pt-icon-font,
  "fork": $pt-icon-fork,
  "form": $pt-icon-form,
  "full-circle": $pt-icon-full-circle,
  "full-stacked-chart": $pt-icon-full-stacked-chart,
  "fullscreen": $pt-icon-fullscreen,
  "function": $pt-icon-function,
  "gantt-chart": $pt-icon-gantt-chart,
  "geolocation": $pt-icon-geolocation,
  "geosearch": $pt-icon-geosearch,
  "git-branch": $pt-icon-git-branch,
  "git-commit": $pt-icon-git-commit,
  "git-merge": $pt-icon-git-merge,
  "git-new-branch": $pt-icon-git-new-branch,
  "git-pull": $pt-icon-git-pull,
  "git-push": $pt-icon-git-push,
  "git-repo": $pt-icon-git-repo,
  "glass": $pt-icon-glass,
  "globe": $pt-icon-globe,
  "globe-network": $pt-icon-globe-network,
  "graph": $pt-icon-graph,
  "graph-remove": $pt-icon-graph-remove,
  "greater-than": $pt-icon-greater-than,
  "greater-than-or-equal-to": $pt-icon-greater-than-or-equal-to,
  "grid": $pt-icon-grid,
  "grid-view": $pt-icon-grid-view,
  "group-objects": $pt-icon-group-objects,
  "grouped-bar-chart": $pt-icon-grouped-bar-chart,
  "hand": $pt-icon-hand,
  "hand-down": $pt-icon-hand-down,
  "hand-left": $pt-icon-hand-left,
  "hand-right": $pt-icon-hand-right,
  "hand-up": $pt-icon-hand-up,
  "header": $pt-icon-header,
  "header-one": $pt-icon-header-one,
  "header-two": $pt-icon-header-two,
  "headset": $pt-icon-headset,
  "heart": $pt-icon-heart,
  "heart-broken": $pt-icon-heart-broken,
  "heat-grid": $pt-icon-heat-grid,
  "heatmap": $pt-icon-heatmap,
  "help": $pt-icon-help,
  "helper-management": $pt-icon-helper-management,
  "highlight": $pt-icon-highlight,
  "history": $pt-icon-history,
  "home": $pt-icon-home,
  "horizontal-bar-chart": $pt-icon-horizontal-bar-chart,
  "horizontal-bar-chart-asc": $pt-icon-horizontal-bar-chart-asc,
  "horizontal-bar-chart-desc": $pt-icon-horizontal-bar-chart-desc,
  "horizontal-distribution": $pt-icon-horizontal-distribution,
  "id-number": $pt-icon-id-number,
  "image-rotate-left": $pt-icon-image-rotate-left,
  "image-rotate-right": $pt-icon-image-rotate-right,
  "import": $pt-icon-import,
  "inbox": $pt-icon-inbox,
  "inbox-filtered": $pt-icon-inbox-filtered,
  "inbox-geo": $pt-icon-inbox-geo,
  "inbox-search": $pt-icon-inbox-search,
  "inbox-update": $pt-icon-inbox-update,
  "info-sign": $pt-icon-info-sign,
  "inheritance": $pt-icon-inheritance,
  "inner-join": $pt-icon-inner-join,
  "insert": $pt-icon-insert,
  "intersection": $pt-icon-intersection,
  "ip-address": $pt-icon-ip-address,
  "issue": $pt-icon-issue,
  "issue-closed": $pt-icon-issue-closed,
  "issue-new": $pt-icon-issue-new,
  "italic": $pt-icon-italic,
  "join-table": $pt-icon-join-table,
  "key": $pt-icon-key,
  "key-backspace": $pt-icon-key-backspace,
  "key-command": $pt-icon-key-command,
  "key-control": $pt-icon-key-control,
  "key-delete": $pt-icon-key-delete,
  "key-enter": $pt-icon-key-enter,
  "key-escape": $pt-icon-key-escape,
  "key-option": $pt-icon-key-option,
  "key-shift": $pt-icon-key-shift,
  "key-tab": $pt-icon-key-tab,
  "known-vehicle": $pt-icon-known-vehicle,
  "lab-test": $pt-icon-lab-test,
  "label": $pt-icon-label,
  "layer": $pt-icon-layer,
  "layers": $pt-icon-layers,
  "layout": $pt-icon-layout,
  "layout-auto": $pt-icon-layout-auto,
  "layout-balloon": $pt-icon-layout-balloon,
  "layout-circle": $pt-icon-layout-circle,
  "layout-grid": $pt-icon-layout-grid,
  "layout-group-by": $pt-icon-layout-group-by,
  "layout-hierarchy": $pt-icon-layout-hierarchy,
  "layout-linear": $pt-icon-layout-linear,
  "layout-skew-grid": $pt-icon-layout-skew-grid,
  "layout-sorted-clusters": $pt-icon-layout-sorted-clusters,
  "learning": $pt-icon-learning,
  "left-join": $pt-icon-left-join,
  "less-than": $pt-icon-less-than,
  "less-than-or-equal-to": $pt-icon-less-than-or-equal-to,
  "lifesaver": $pt-icon-lifesaver,
  "lightbulb": $pt-icon-lightbulb,
  "link": $pt-icon-link,
  "list": $pt-icon-list,
  "list-columns": $pt-icon-list-columns,
  "list-detail-view": $pt-icon-list-detail-view,
  "locate": $pt-icon-locate,
  "lock": $pt-icon-lock,
  "log-in": $pt-icon-log-in,
  "log-out": $pt-icon-log-out,
  "manual": $pt-icon-manual,
  "manually-entered-data": $pt-icon-manually-entered-data,
  "map": $pt-icon-map,
  "map-create": $pt-icon-map-create,
  "map-marker": $pt-icon-map-marker,
  "maximize": $pt-icon-maximize,
  "media": $pt-icon-media,
  "menu": $pt-icon-menu,
  "menu-closed": $pt-icon-menu-closed,
  "menu-open": $pt-icon-menu-open,
  "merge-columns": $pt-icon-merge-columns,
  "merge-links": $pt-icon-merge-links,
  "minimize": $pt-icon-minimize,
  "minus": $pt-icon-minus,
  "mobile-phone": $pt-icon-mobile-phone,
  "mobile-video": $pt-icon-mobile-video,
  "moon": $pt-icon-moon,
  "more": $pt-icon-more,
  "mountain": $pt-icon-mountain,
  "move": $pt-icon-move,
  "mugshot": $pt-icon-mugshot,
  "multi-select": $pt-icon-multi-select,
  "music": $pt-icon-music,
  "new-drawing": $pt-icon-new-drawing,
  "new-grid-item": $pt-icon-new-grid-item,
  "new-layer": $pt-icon-new-layer,
  "new-layers": $pt-icon-new-layers,
  "new-link": $pt-icon-new-link,
  "new-object": $pt-icon-new-object,
  "new-person": $pt-icon-new-person,
  "new-prescription": $pt-icon-new-prescription,
  "new-text-box": $pt-icon-new-text-box,
  "ninja": $pt-icon-ninja,
  "not-equal-to": $pt-icon-not-equal-to,
  "notifications": $pt-icon-notifications,
  "notifications-updated": $pt-icon-notifications-updated,
  "numbered-list": $pt-icon-numbered-list,
  "numerical": $pt-icon-numerical,
  "office": $pt-icon-office,
  "offline": $pt-icon-offline,
  "oil-field": $pt-icon-oil-field,
  "one-column": $pt-icon-one-column,
  "outdated": $pt-icon-outdated,
  "page-layout": $pt-icon-page-layout,
  "panel-stats": $pt-icon-panel-stats,
  "panel-table": $pt-icon-panel-table,
  "paperclip": $pt-icon-paperclip,
  "paragraph": $pt-icon-paragraph,
  "path": $pt-icon-path,
  "path-search": $pt-icon-path-search,
  "pause": $pt-icon-pause,
  "people": $pt-icon-people,
  "percentage": $pt-icon-percentage,
  "person": $pt-icon-person,
  "phone": $pt-icon-phone,
  "pie-chart": $pt-icon-pie-chart,
  "pin": $pt-icon-pin,
  "pivot": $pt-icon-pivot,
  "pivot-table": $pt-icon-pivot-table,
  "play": $pt-icon-play,
  "plus": $pt-icon-plus,
  "polygon-filter": $pt-icon-polygon-filter,
  "power": $pt-icon-power,
  "predictive-analysis": $pt-icon-predictive-analysis,
  "prescription": $pt-icon-prescription,
  "presentation": $pt-icon-presentation,
  "print": $pt-icon-print,
  "projects": $pt-icon-projects,
  "properties": $pt-icon-properties,
  "property": $pt-icon-property,
  "publish-function": $pt-icon-publish-function,
  "pulse": $pt-icon-pulse,
  "random": $pt-icon-random,
  "record": $pt-icon-record,
  "redo": $pt-icon-redo,
  "refresh": $pt-icon-refresh,
  "regression-chart": $pt-icon-regression-chart,
  "remove": $pt-icon-remove,
  "remove-column": $pt-icon-remove-column,
  "remove-column-left": $pt-icon-remove-column-left,
  "remove-column-right": $pt-icon-remove-column-right,
  "remove-row-bottom": $pt-icon-remove-row-bottom,
  "remove-row-top": $pt-icon-remove-row-top,
  "repeat": $pt-icon-repeat,
  "reset": $pt-icon-reset,
  "resolve": $pt-icon-resolve,
  "rig": $pt-icon-rig,
  "right-join": $pt-icon-right-join,
  "ring": $pt-icon-ring,
  "rotate-document": $pt-icon-rotate-document,
  "rotate-page": $pt-icon-rotate-page,
  "satellite": $pt-icon-satellite,
  "saved": $pt-icon-saved,
  "scatter-plot": $pt-icon-scatter-plot,
  "search": $pt-icon-search,
  "search-around": $pt-icon-search-around,
  "search-template": $pt-icon-search-template,
  "search-text": $pt-icon-search-text,
  "segmented-control": $pt-icon-segmented-control,
  "select": $pt-icon-select,
  "selection": $pt-icon-selection,
  "send-to": $pt-icon-send-to,
  "send-to-graph": $pt-icon-send-to-graph,
  "send-to-map": $pt-icon-send-to-map,
  "series-add": $pt-icon-series-add,
  "series-configuration": $pt-icon-series-configuration,
  "series-derived": $pt-icon-series-derived,
  "series-filtered": $pt-icon-series-filtered,
  "series-search": $pt-icon-series-search,
  "settings": $pt-icon-settings,
  "share": $pt-icon-share,
  "shield": $pt-icon-shield,
  "shop": $pt-icon-shop,
  "shopping-cart": $pt-icon-shopping-cart,
  "signal-search": $pt-icon-signal-search,
  "sim-card": $pt-icon-sim-card,
  "slash": $pt-icon-slash,
  "small-cross": $pt-icon-small-cross,
  "small-minus": $pt-icon-small-minus,
  "small-plus": $pt-icon-small-plus,
  "small-tick": $pt-icon-small-tick,
  "snowflake": $pt-icon-snowflake,
  "social-media": $pt-icon-social-media,
  "sort": $pt-icon-sort,
  "sort-alphabetical": $pt-icon-sort-alphabetical,
  "sort-alphabetical-desc": $pt-icon-sort-alphabetical-desc,
  "sort-asc": $pt-icon-sort-asc,
  "sort-desc": $pt-icon-sort-desc,
  "sort-numerical": $pt-icon-sort-numerical,
  "sort-numerical-desc": $pt-icon-sort-numerical-desc,
  "split-columns": $pt-icon-split-columns,
  "square": $pt-icon-square,
  "stacked-chart": $pt-icon-stacked-chart,
  "star": $pt-icon-star,
  "star-empty": $pt-icon-star-empty,
  "step-backward": $pt-icon-step-backward,
  "step-chart": $pt-icon-step-chart,
  "step-forward": $pt-icon-step-forward,
  "stop": $pt-icon-stop,
  "stopwatch": $pt-icon-stopwatch,
  "strikethrough": $pt-icon-strikethrough,
  "style": $pt-icon-style,
  "swap-horizontal": $pt-icon-swap-horizontal,
  "swap-vertical": $pt-icon-swap-vertical,
  "symbol-circle": $pt-icon-symbol-circle,
  "symbol-cross": $pt-icon-symbol-cross,
  "symbol-diamond": $pt-icon-symbol-diamond,
  "symbol-square": $pt-icon-symbol-square,
  "symbol-triangle-down": $pt-icon-symbol-triangle-down,
  "symbol-triangle-up": $pt-icon-symbol-triangle-up,
  "tag": $pt-icon-tag,
  "take-action": $pt-icon-take-action,
  "taxi": $pt-icon-taxi,
  "text-highlight": $pt-icon-text-highlight,
  "th": $pt-icon-th,
  "th-derived": $pt-icon-th-derived,
  "th-disconnect": $pt-icon-th-disconnect,
  "th-filtered": $pt-icon-th-filtered,
  "th-list": $pt-icon-th-list,
  "thumbs-down": $pt-icon-thumbs-down,
  "thumbs-up": $pt-icon-thumbs-up,
  "tick": $pt-icon-tick,
  "tick-circle": $pt-icon-tick-circle,
  "time": $pt-icon-time,
  "timeline-area-chart": $pt-icon-timeline-area-chart,
  "timeline-bar-chart": $pt-icon-timeline-bar-chart,
  "timeline-events": $pt-icon-timeline-events,
  "timeline-line-chart": $pt-icon-timeline-line-chart,
  "tint": $pt-icon-tint,
  "torch": $pt-icon-torch,
  "tractor": $pt-icon-tractor,
  "train": $pt-icon-train,
  "translate": $pt-icon-translate,
  "trash": $pt-icon-trash,
  "tree": $pt-icon-tree,
  "trending-down": $pt-icon-trending-down,
  "trending-up": $pt-icon-trending-up,
  "truck": $pt-icon-truck,
  "two-columns": $pt-icon-two-columns,
  "unarchive": $pt-icon-unarchive,
  "underline": $pt-icon-underline,
  "undo": $pt-icon-undo,
  "ungroup-objects": $pt-icon-ungroup-objects,
  "unknown-vehicle": $pt-icon-unknown-vehicle,
  "unlock": $pt-icon-unlock,
  "unpin": $pt-icon-unpin,
  "unresolve": $pt-icon-unresolve,
  "updated": $pt-icon-updated,
  "upload": $pt-icon-upload,
  "user": $pt-icon-user,
  "variable": $pt-icon-variable,
  "vertical-bar-chart-asc": $pt-icon-vertical-bar-chart-asc,
  "vertical-bar-chart-desc": $pt-icon-vertical-bar-chart-desc,
  "vertical-distribution": $pt-icon-vertical-distribution,
  "video": $pt-icon-video,
  "volume-down": $pt-icon-volume-down,
  "volume-off": $pt-icon-volume-off,
  "volume-up": $pt-icon-volume-up,
  "walk": $pt-icon-walk,
  "warning-sign": $pt-icon-warning-sign,
  "waterfall-chart": $pt-icon-waterfall-chart,
  "widget": $pt-icon-widget,
  "widget-button": $pt-icon-widget-button,
  "widget-footer": $pt-icon-widget-footer,
  "widget-header": $pt-icon-widget-header,
  "wrench": $pt-icon-wrench,
  "zoom-in": $pt-icon-zoom-in,
  "zoom-out": $pt-icon-zoom-out,
  "zoom-to-fit": $pt-icon-zoom-to-fit,
);
