import * as React from "react";
interface Props {
    prompt: string;
    password: boolean;
    submitPromptReply: any;
}
interface State {
    value: string;
}
export declare class PromptRequest extends React.PureComponent<Props, State> {
    constructor(props: Props);
    handleSubmitPromptReply(event: React.FormEvent<HTMLFormElement>): void;
    handleChange(event: React.ChangeEvent<HTMLInputElement>): void;
    render(): JSX.Element;
}
export default PromptRequest;
