import * as React from "react";
import { StyledComponent } from "styled-components";
interface CellProps {
    /**
     * Indicates if a cell is selected
     */
    isSelected?: boolean;
    /**
     * Indicates if hovering over a cell
     */
    _hovered?: boolean;
    /**
     * Style children when a cell is selected or hovered over
     */
    children?: React.ReactNode;
}
export declare const Cell: StyledComponent<"div", any, CellProps, never>;
export default Cell;
