import { ImmutableStreamOutput } from "@nteract/commutable";
import * as React from "react";
interface Props {
    output_type: "stream";
    output: ImmutableStreamOutput;
}
export declare class StreamText extends React.PureComponent<Props> {
    static defaultProps: {
        output: null;
        output_type: string;
    };
    render(): JSX.Element | null;
}
export default StreamText;
