"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
const MathJax = __importStar(require("@nteract/mathjax"));
const React = __importStar(require("react"));
class LaTeX extends React.PureComponent {
    render() {
        return React.createElement(MathJax.Text, null, this.props.data);
    }
}
exports.LaTeX = LaTeX;
LaTeX.defaultProps = {
    data: "",
    mediaType: "text/latex"
};
exports.default = LaTeX;
