import { MarkdownAbstractSyntaxTree, RenderProps } from "react-markdown";
export interface Attachments {
    /** An object of attachment names to string content. This will be used to look up image content when a image node is encountered */
    [attachmentName: string]: string;
}
export default function attachmentTransformer(attachments?: Attachments): (node: MarkdownAbstractSyntaxTree, renderProps?: RenderProps) => MarkdownAbstractSyntaxTree;
